==> klat4-0.5.2.tar.bz2: klat4-0.5.2/klateditwidget.h <==
/*
    Klat - A LaTeX editor for KDE
    
    Copyright (C) 2002-2004  Jori Liesenborgs (jori@lumumba.luc.ac.be)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef KLATEDITWIDGET_H

#define KLATEDITWIDGET_H

#include <kurl.h>
#include <ktexteditor/document.h>
#include <ktexteditor/editor.h>
#include <ktexteditor/view.h>
#include <ktexteditor/cursor.h>
#include <Qt/qframe.h>

class QString;
class QEvent;
class KlatDocumentNode;
class KlatToolTab;
class KListView;
class KListViewItem;

class KlatEditWidget : public QFrame
{
	Q_OBJECT
public:
	KlatEditWidget(QWidget *parent);
	~KlatEditWidget();
	int cursorLine()					{ return view->cursorPositionVirtual().line(); }
	int cursorColumn()					{ return view->cursorPositionVirtual().column(); }
	int cursorColumnReal()					{ return view->cursorPosition().column(); }
	void insertText(int row,int col,const QString &str)	{ KTextEditor::Cursor pos(row,col); doc->insertText(pos,str); }
	void setCursorPositionReal(int row,int col)		{ KTextEditor::Cursor pos(row,col); view->setCursorPosition(pos); }
	KUrl url()						{ return doc->url(); }
	bool isModified()					{ return doc->isModified(); }
	bool save()						{ if(doc->documentSave()) return true; else return false; }
	void setFocus()						{ view->setFocus(); }
	KTextEditor::View * getView()				{ return view; }
	static void configDialog();
	void readConfig()					{ /*doc->readConfig();*/ }
signals:
	void cursorPositionChanged();
public slots:
	bool openUrl(const KUrl &url);
private slots:
	void slotCursorPositionChanged();
	void slotModeChanged();
	void slotHighlightingModeChanged();
private:
	void resizeEvent(QResizeEvent *);
	
	KTextEditor::Document *doc;
	KTextEditor::View *view;
};

#endif // KLATEDITWIDGET_H

==> klat4-0.6.1.tar.bz2: klat4-0.6.1/klateditwidget.h <==
/*
    Klat4 - A LaTeX editor for KDE4
    
    Copyright (C) 2008  Anna A. Ladilova (ladilova@algebraic.ru)
    Copyright (C) 2002-2004  Jori Liesenborgs (jori@lumumba.luc.ac.be)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef KLATEDITWIDGET_H

#define KLATEDITWIDGET_H

#include <KUrl>
#include <KTextEditor/Document>
#include <KTextEditor/Editor>
#include <KTextEditor/View>
#include <KTextEditor/Cursor>
#include <QFrame>

class QString;
class KlatToolTab;

class KlatEditWidget : public QFrame
{
	Q_OBJECT
public:
	KlatEditWidget(QWidget *parent);
	~KlatEditWidget();
	int cursorLine();
	int cursorColumn();
	int cursorColumnReal();
	void insertText(int row,int col,const QString &str);
	void setCursorPositionReal(int row,int col);
	KUrl url()						{ return doc->url(); }
	bool isModified()					{ return doc->isModified(); }
	bool save();
	void setFocus()						{ view->setFocus(); }
	KTextEditor::View * getView()				{ return view; }
	static void configDialog();
signals:
	void cursorPositionChanged();
	void documentNameChanged(KlatEditWidget *,QString);
public slots:
	bool openUrl(const KUrl &url);
private slots:
	void slotCursorPositionChanged();
	void slotModeChanged();
	void slotHighlightingModeChanged();
	void slotDocNameChanged();
private:
	void resizeEvent(QResizeEvent *);
	
	KTextEditor::Document *doc;
	KTextEditor::View *view;
};

#endif // KLATEDITWIDGET_H
